from setuptools import setup, find_packages

setup(
    name='yourmove',
    version='0.0.0.1',
    description='YourMove',
    author='jup014',
    author_email='jup014@ucsd.edu',
    url='https://cwphs.ucsd.edu',
    license='MIT',
    py_modules=['yourmove'],
    python_requires='>=3',
    install_requires=['pytz'],
    packages=['yourmove']
)